@@ -12,12 +12,6 @@ class VMTemplateContent(PluginTemplateExtension):
         obj = self.context.get("object")
 
         drives_id = StorageConfigurationDrive.objects.values('drive').filter(virtual_machine=obj)
-        print(f"Drives id: {drives_id}")
-        drives = []
-        for drive_id in drives_id:
-            drives.append(Drive.objects.get(pk=drive_id))
-
-        print(f"drives: {drives}")
         partition_dict = {}
         for drive_id in drives_id:
             print(f"Drive ID: {drive_id['drive']}")
